backfill_iofv: Add individual objective function to data

View source: R/xp_xtras.R

backfill_iofvR Documentation

Add individual objective function to data

Description

Add individual objective function to data

Usage

backfill_iofv(xpdb, .problem = NULL, .subprob = NULL, .label = "iOFV")

Arguments

xpdb

<xpose_data> or <xp_xtras> object

.problem

Problem number

.subprob

Subproblem number

.label

The name of the new column. iOFV is the default.

Details

This function will only work for objects with software listed as nonmem or nlmixr2. For nonmem, the object should haves a phi file and with an OBJ column in that file. For nlmixr2, the fit object data should have individual observation likelihoods in a column called NLMIXRLLIKOBS (this is a current standard, but is checked at runtime).

Value

<xp_xtras> object with new column in the data and a column with iofv var type.

Examples


xpdb_x %>%
  backfill_iofv() %>%
  list_vars()


xpose.xtras documentation built on April 22, 2026, 1:09 a.m.