diagram_lineage: Visualize 'xpose_set'

View source: R/xset_diagram.R

diagram_lineageR Documentation

Visualize xpose_set

Description

[Experimental]

In its current state, this function is intended to provide a simple visual representation of an xpose_set. Functionality and aesthetic enhancements are expected in future releases.

Usage

diagram_lineage(xpdb_s, ...)

Arguments

xpdb_s

<xpose_set> object

...

For later expansion. Will be ignored.

Value

A DiagrammeR-compliant graph object.

Examples

## Not run: 
diagram_lineage(pheno_set) %>%
  DiagrammeR::render_graph(layout="tree")

## End(Not run)


xpose.xtras documentation built on April 22, 2026, 1:09 a.m.