list_dv_probs: For a categorical DV variable, show associated probabilities

View source: R/categorical.R

list_dv_probsR Documentation

For a categorical DV variable, show associated probabilities

Description

A convenient quick check for how probabilities are currently assigned, based on set_dv_probs.

Usage

list_dv_probs(xpdb, .problem = NULL, .dv_var = NULL)

Arguments

xpdb

<xp_xtras> object

.problem

<numeric> Problem number to use. Uses all problems if NULL (the default). May be omitted entirely and left to default, even when formulas are supplied positionally in ....

.dv_var

<tidyselect> of column having the categorical observation. Default is first-listed catdv.

Value

<tibble> of probabilities

Examples


pkpd_m3 %>%
  set_dv_probs(1, 1~LIKE, .dv_var = BLQ) %>%
  list_dv_probs(.dv_var=BLQ)


xpose.xtras documentation built on Sept. 1, 2026, 5:08 p.m.