Skip to contents

A wrapper that executes the pipeline:

Usage

nlmixr2_as_xtra(obj, ..., .skip_assoc = FALSE)

Arguments

obj

nlmixr2 fit object

...

Passed to xpose_data_nlmixr2

.skip_assoc

<logical> If the model is relatively uncomplicated, nlmixr2_prm_associations() may be able to recognize relationships between random effects and fixed effect parameters. If the default (FALSE) fails then try to rerun with the association step skipped.

Value

An <xp_xtra> object with fit attached

See also