set_default_labs: Set default plot label overrides on an 'xp_xtras' object

View source: R/xtra_labs.R

set_default_labsR Documentation

Set default plot label overrides on an xp_xtras object

Description

Stores title/subtitle/caption/tag templates on xpdb that apply_default_labs() will use to fill in (or overwrite) labels on any plot built from this xpdb, when xpdb is passed to it. Values may contain the same ⁠@keyword⁠ placeholders understood by xpose::parse_title() (e.g. "@nind", "@nobs", "@run"), since they are resolved the same way.

Usage

set_default_labs(xpdb, ...)

Arguments

xpdb

<xpose_data> or <xp_xtras> object

...

<dynamic-dots> One or more of title, subtitle, caption, tag, given as character strings

Value

xp_xtras object

See Also

set_xtras_options() for the session-option equivalent (xpose.xtras.default_labs), and get_xtras_option() to check which one is currently dominant.

Examples

xpdb_x <- set_default_labs(xpdb_x, caption = "@nobs observations in @nind individuals")
p <- xpose::dv_vs_ipred(xpdb_x)
apply_default_labs(p, xpdb = xpdb_x)

xpose.xtras documentation built on Sept. 1, 2026, 5:08 p.m.