Skip to contents

Stores default add_watermark() arguments on xpdb that add_watermark() will use for any of label/colour/alpha/size/ angle/fontface not otherwise supplied, when xpdb is passed to it.

Usage

set_default_watermark(xpdb, ...)

Arguments

xpdb

<xpose_data> or <xp_xtras> object

...

<dynamic-dots> One or more of label, colour, alpha, size, angle, fontface

Value

xp_xtras object

See also

set_xtras_options() for the session-option equivalent (xpose.xtras.default_watermark), and get_xtras_option() to check which one is currently dominant.

Examples

xpdb_x <- set_default_watermark(xpdb_x, label = "PRELIMINARY", colour = "red")
p <- xpose::dv_vs_ipred(xpdb_x)
#> Using data from $prob no.1
#> Filtering data by EVID == 0
add_watermark(p, xpdb = xpdb_x)
#> `geom_smooth()` using formula = 'y ~ x'