This is intended to be used as a convenience function in plotting where levels are set for some variable.
Value
A vector of levels corresponding to the input vector. If
lvl_tbl carries an ordered attribute set to TRUE (see
set_var_levels()'s .ordered argument and lvl_inord()), the
result is an ordered factor.