If no base model is provided, and if lineage is unclear, the first model in
the xpose_set is used as the base model, exactly as in <diff.xpose_set>.
Unlike diff(), values are not differenced, so a straightforward
model-to-model comparison is possible.
As with the xpose_data methods, a component model that is itself a
model-averaged ("franken") object will cause an error.
Arguments
- object
<
xpose_set> object- ...
<
dynamic-dots> Passed to <xset_lineage>..spinner=FALSEcan also be set here.- k
<
numeric> Penalty per parameter, as in <stats::AIC>.
Value
<numeric> vector, or list thereof, following <xset_lineage>.