Visualizes the parameter correlation (or covariance) matrix as a heatmap,
filling a gap left behind in translation from xpose4. Values come from
get_cov_matrix(), which has built-in support for nonmem and
nlmixr2 models; rendering is done with the generic xplot_heatmap()
template.
cormat(
xpdb,
type = c("correlation", "covariance"),
.problem = NULL,
.subprob = NULL,
.method = NULL,
drop_fixed = TRUE,
digits,
title,
subtitle = "Ofv: @ofv, Condition number: @condn",
caption = "@dir",
tag = NULL,
quiet,
...
)The desired plot
<xp_xtras> or <xpose_data> object
<character> Either "correlation" (default) or "covariance"
<numeric> Problem number to use. Uses the xpose default if not provided.
<numeric> Subproblem number to use. Uses the xpose default if not provided.
<character> Method to use. Uses the xpose default if not provided.
<logical> Passed to get_cov_matrix()
Number of significant digits to display in cell labels. Defaults to reportable_digits()
Plot title
Plot subtitle
Plot caption
Plot tag
Silence extra debugging output
Additional aesthetics, passed to xplot_heatmap()
Only the upper triangle of the matrix is drawn, as it is symmetric.
Fixed-effect (theta) and random-effect (omega/sigma) parameters are
both included for nonmem models, when available and not fixed. For
nlmixr2 models, only fixed effects are included, as nlmixr2 does not
report uncertainty for random effects. See get_cov_matrix() for
further details on availability; if the covariance step was not run, or
did not complete successfully, an informative error is raised.
cormat(xpdb_x)
cormat(xpdb_x, type = "covariance")
Run the code above in your browser using DataLab