# Select two xpdb objects to focus on
xpdb_set %>% focus_xpdb(mod2,fix1)
# Add a focus
xpdb_set %>% focus_xpdb(mod2,fix1) %>% focus_xpdb(mod1, .add=TRUE)
# Remove focus
xpdb_set %>% focus_xpdb(mod2,fix1) %>% focus_xpdb()
if (FALSE) {
# Focus function and tidyselect
pheno_set %>%
focus_xpdb(everything()) %>%
# Add iOFV col and iofv type to all xpdbs in set
focus_function(backfill_iofv) %>%
# Show 1... can do all like this, too, but no need
unfocus_xpdb() %>%
select(run6) %>%
{.[[1]]$xpdb} %>%
list_vars()
# Quick-apply version of previous example
pheno_set %>%
focus_qapply(backfill_iofv) %>%
select(run6) %>%
{.[[1]]$xpdb} %>%
list_vars()
}
# Output-generating function applied to a single focused element:
# returns the plot itself, not an xpose_set
pheno_set %>%
focus_xpdb(run6) %>%
focus_function(xpose::dv_vs_ipred)
# ... or with several elements focused, a named list of plots
pheno_set %>%
focus_xpdb(run6, run7) %>%
focus_function(xpose::dv_vs_ipred)
Run the code above in your browser using DataLab