mutate_files: Mutate the file table for an xpose data object

mutate_filesR Documentation

Mutate the file table for an xpose data object

Description

Mutate the file table for an xpose data object

Usage

mutate_files(xpdb, ...)

Arguments

xpdb

<⁠xpose data⁠> object

...

Forwarded to mutate()


xpose.xtras documentation built on April 19, 2026, 9:06 a.m.