Convenience function for ingesting an nlmixr2 model to xpose and xpose.xtras
Source:R/nlmixr2.R
nlmixr2_as_xtra.RdA wrapper that executes the pipeline:
obj %>%
xpose.nlmixr2::xpose_data_nlmixr2() %>%
attach_nlmixr2() %>%
as_xp_xtras() %>%
backfill_nlmixr2_props() %>%
`if`(.skip_assoc, ., nlmixr2_prm_associations(.))Arguments
- obj
nlmixr2 fit object
- ...
Passed to xpose_data_nlmixr2
- .skip_assoc
<
logical> If the model is relatively uncomplicated,nlmixr2_prm_associations()may be able to recognize relationships between random effects and fixed effect parameters. If the default (FALSE) fails then try to rerun with the association step skipped.