Based on associations baked into nlmixr2, automatically add to xpose data
Source:R/nlmixr2.R
nlmixr2_prm_associations.RdThis function attempts to discern the associations between omegas and thetas
using information about mu referencing within the nlmixr2 fit object.
Details
Back-transformations are not as relevant here as they may seem. Manual
back-transformation with backTransform() only affects the display of the
back-transformed theta estimate (and CI), but does not impact the
relationship between EBEs and individual parameter estimates.
Examples
if (FALSE) { # \dontrun{
nlmixr2_warfarin <- nlmixr_example("nlmixr2_warfarin")
nlmixr2_warfarin %>%
# This will add all log-normal and the logitnormal params
nlmixr2_prm_associations() %>%
# Make sure theta is in normal scale
# rxode::expit could be plogis in this case
mutate_prm(temax ~ rxode2::expit) %>%
# Review results
get_prm()
} # }