| nlmixr2_prm_associations | R Documentation |
This function attempts to discern the associations between omegas and thetas
using information about mu referencing within the nlmixr2 fit object.
nlmixr2_prm_associations(xpdb, dry_run = FALSE, quiet)
xpdb |
< |
dry_run |
< |
quiet |
< |
Back-transformations are not as relevant here as they may seem. Manual
back-transformation with backTransform() only affects the display of the
back-transformed theta estimate (and CI), but does not impact the
relationship between EBEs and individual parameter estimates.
Object with filled par
rxode2::ini()
## Not run:
nlmixr2_warfarin %>%
# This will add all log-normal and the logitnormal params
nlmixr2_prm_associations() %>%
# Make sure theta is in normal scale
# rxode::expit could be plogis in this case
mutate_prm(temax~rxode2::expit) %>%
# Review results
get_prm()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.