test_nlmixr2_has_fit: Test if xpose data object has a fit object

View source: R/nlmixr2.R

test_nlmixr2_has_fitR Documentation

Test if xpose data object has a fit object

Description

Test if xpose data object has a fit object

Usage

test_nlmixr2_has_fit(xpdb)

Arguments

xpdb

<xpose_data> object


xpose.xtras documentation built on April 19, 2026, 9:06 a.m.