| val2lvl | R Documentation |
This is intended to be used as a convenience function in plotting where levels are set for some variable.
val2lvl(vals, lvl_tbl = NULL)
vals |
vector of values associated with levels in |
lvl_tbl |
tibble of levels |
A vector of levels corresponding to the input vector. If
lvl_tbl carries an ordered attribute set to TRUE (see
set_var_levels()'s .ordered argument and lvl_inord()), the
result is an ordered factor.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.