val2lvl: Translate values to levels
Description
This is intended to be used as a convenience function
in plotting where levels are set for some variable.
Usage
val2lvl(vals, lvl_tbl = NULL)
Value
A vector of levels corresponding to the input vector. If
lvl_tbl carries an ordered attribute set to TRUE (see
set_var_levels()'s .ordered argument and lvl_inord()), the
result is an ordered factor.
Arguments
- vals
vector of values associated with levels in lvl_tbl
- lvl_tbl
tibble of levels