| logLik.xpose_set | R Documentation |
xpose_setIf no base model is provided, and if lineage is unclear, the first model in
the xpose_set is used as the base model, exactly as in <diff.xpose_set>.
Unlike diff(), values are not differenced, so a straightforward
model-to-model comparison is possible.
As with the xpose_data methods, a component model that is itself a
model-averaged ("franken") object will cause an error.
## S3 method for class 'xpose_set'
logLik(object, ...)
## S3 method for class 'xpose_set'
AIC(object, ..., k = 2)
## S3 method for class 'xpose_set'
BIC(object, ...)
object |
< |
... |
< |
k |
< |
<numeric> vector, or list thereof, following <xset_lineage>.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.